#!/bin/ksh
#
# COM2mtx.sh - combined Loader and CP/M .COM file to make tape
#

d=`dirname $0`

if [[ "$1" = "" ]] ; then
	print "usage: $0 FILE"
	exit 1
fi

if [[ ! -r "$1.COM" ]] ; then
	print "$0: can't read $1.COM"
	exit 2
fi

# Work out name and size
b=`basename $1`
typeset -L8 fn=${b%.*}
size=`stat -c %s "$1.COM"`

# Write FF and 8 bytes of tape filename
printf "\377$fn" > "$1.mtx"

# Append rest of Loader.mtx
dd if=$d/Loader.mtx seek=9 "of=$1.mtx" skip=9 bs=1 2> /dev/null

# Append CSAVE header
printf "\252${fn}COM" >> "$1.mtx"

# Old trick I used to do with awk stopped working
# so now I exploit ksh to output the length bytes
# https://blog.fpmurphy.com/2017/08/manipulating-binary-data-using-the-korn-shell.html
typeset -i8 lo=$(( size & 256 ))
typeset -i8 hi=$(( size / 256 ))
print -f "\\${lo#8#}\\${hi#8#}" >> "$1.mtx"

# Append CP/M .COM file
cat "$1.COM" >> "$1.mtx"
